@@ -35,7 +35,7 @@
 /***
  ***	DNS Performance Testing Tool
  ***
- ***	Version $Id: dnsperf.c 73079 2006-08-15 23:02:37Z bwelling $
+ ***	Version $Id: dnsperf.c 78122 2006-12-20 21:20:45Z bwelling $
  ***/
 
 #include "common.h"
@@ -524,7 +524,7 @@ retire_old_queries(void) {
 	struct query_status *s;
 
 	while (ISC_TRUE) {
-		s = ISC_LIST_HEAD(outstanding_list);
+		s = ISC_LIST_TAIL(outstanding_list);
 		if (s == NULL ||
 		    (difftv(&time_now, &s->sent_timestamp) < query_timeout))
 			break;
@@ -558,7 +558,7 @@ cancel_queries(void) {
 	struct query_status *s;
 
 	while (ISC_TRUE) {
-		s = ISC_LIST_HEAD(outstanding_list);
+		s = ISC_LIST_TAIL(outstanding_list);
 		if (s == NULL)
 			break;
 		ISC_LIST_UNLINK(outstanding_list, s, link);
